@@ -5,7 +5,7 @@ use warnings;
 use Test2::API qw( context );
 
 # ABSTRACT: Run object
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 sub out    { shift->{out} }
@@ -134,6 +134,7 @@ sub note
     $ctx->note("  $_") for split /\r?\n/, $self->err;
   }
   $ctx->release;
+  $self;
 }
 
 
@@ -154,6 +155,7 @@ sub diag
     $ctx->diag("  $_") for split /\r?\n/, $self->err;
   }
   $ctx->release;
+  $self;
 }
 
 1;
@@ -170,7 +172,7 @@ Test::Alien::Run - Run object
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -215,6 +217,9 @@ The signal that killed the run, or zero if the process was terminated normally.
 
 =head1 METHODS
 
+These methods return the run object itself, so they can be chained,
+as in the synopsis above.
+
 =head2 success
 
  $run->success;
